==> apache-camel-3.1.0-src.zip: apache-camel-3.1.0/core/camel-core/src/test/java/org/apache/camel/PropertyBindingExceptionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel;

import org.junit.Test;

import static org.junit.Assert.assertTrue;

public class PropertyBindingExceptionTest {
    public static final String EXPECTED_EXCEPTION_MESSAGE = "Error binding property (prefix.property=value) with name: property";

    @Test
    public void exceptionMessageTest() {
        PropertyBindingException pbe = new PropertyBindingException(new Object(), "property", "value", "prefix", "property", new Throwable("The casue!"));
        assertTrue("PropertyBindingException message should start with [" + EXPECTED_EXCEPTION_MESSAGE + "] while is [" + pbe.getMessage() + "] instead.",
                pbe.getMessage().startsWith(EXPECTED_EXCEPTION_MESSAGE));

        pbe = new PropertyBindingException(new Object(), "property", "value", "prefix.", "property", new Throwable("The casue!"));
        assertTrue("PropertyBindingException message should start with [" + EXPECTED_EXCEPTION_MESSAGE + "] while is [" + pbe.getMessage() + "] instead.",
                pbe.getMessage().startsWith(EXPECTED_EXCEPTION_MESSAGE));
    }
}

==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/core/camel-core/src/test/java/org/apache/camel/PropertyBindingExceptionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel;

import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;

public class PropertyBindingExceptionTest {
    public static final String EXPECTED_EXCEPTION_MESSAGE = "Error binding property (prefix.property=value) with name: property";

    @Test
    public void exceptionMessageTest() {
        PropertyBindingException pbe = new PropertyBindingException(new Object(), "property", "value", "prefix", "property", new Throwable("The casue!"));
        assertTrue(pbe.getMessage().startsWith(EXPECTED_EXCEPTION_MESSAGE),
                "PropertyBindingException message should start with [" + EXPECTED_EXCEPTION_MESSAGE + "] while is [" + pbe.getMessage() + "] instead.");

        pbe = new PropertyBindingException(new Object(), "property", "value", "prefix.", "property", new Throwable("The casue!"));
        assertTrue(pbe.getMessage().startsWith(EXPECTED_EXCEPTION_MESSAGE),
                "PropertyBindingException message should start with [" + EXPECTED_EXCEPTION_MESSAGE + "] while is [" + pbe.getMessage() + "] instead.");
    }
}
